"""
@Time : 2023/8/2 10:00 
@Author : skyoceanchen
@TEL: 18916403796
@项目：email_operations
@File : email_operations.by
@PRODUCT_NAME :PyCharm
"""
import smtplib
from email.mime.text import MIMEText
from email.mime.image import MIMEImage
from email.mime.multipart import MIMEMultipart
from email.mime.application import MIMEApplication
from email.header import Header
import datetime
import configparser


class EmailOperations(object):
    # 创建一个解析器
    config = configparser.ConfigParser()

    def __init__(self, conf_path):
        self.config.read(conf_path, encoding='utf-8')

    def read_config(self):
        self.config.options('from_user')
        self.from_email = self.config.get('from_user', 'from_email')
        self.passwd = self.config.get('from_user', 'passwd')

    def start_send(self, subject, to_user):
        self.msg['Subject'] = subject
        self.msg['From'] = self.from_email
        self.msg['To'] = Header(",".join(to_user))
        self.msg['Date'] = Header(datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'),
                                  'utf-8')  # 时间可以这么获取：datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S')
        s = smtplib.SMTP_SSL("smtp.qq.com", 465)
        s.login(self.from_email, self.passwd)
        try:
            s.sendmail(self.from_email, to_user, self.msg.as_string())
            # print(s.c)
            # print(f"{msg_from}  -> {subject} -> {msg_to}-> 发送{len(msg_to)}成功")
            #     源邮箱  -> 主题 -> 目标邮箱-> 是否发送成功
            return True
        except smtplib.SMTPException as e:
            s.quit()
            # print(f"{msg_from}  -> {subject} -> {msg_to}-> 发送失败，错误{str(e)}")
            return False
        finally:
            s.quit()

    def send_email(self, subject=None, to_user=None, send_content=None, send_html_file=None, send_html_img=None,
                   file_path=None, send_img=None):
        """
        :param subject: 主题
        :param to_user: 发送到那些人
        :param send_content: 发送内容
        :param send_html_file: 发送html内容
        :param send_html_img: 发送html内的图片，与send_html_file一起使用
        :param file_path: 发送附件
        :param send_img: 发送的图片
        :return:
        """
        self.msg = MIMEMultipart()
        if send_content:
            self.msg.attach(MIMEText(send_content))
        if send_html_file:
            f = open(send_html_file, 'rb')  # HTML文件默认和当前文件在同一路径下，若不在同一路径下，需要指定要发送的HTML文件的路径
            mail_body = f.read()
            f.close()
            if send_html_img:
                for index, tu_path in enumerate(send_html_img):
                    # 将图片显示在正文
                    with open(tu_path, 'rb') as f:
                        # 图片添加到正文
                        msgImage = MIMEImage(f.read())
                        # 定义图片ID
                        image_index = index + 1  # 可以添加9个图片，需要更多的话需要修改index,
                        """
                        这里是把图片发布到邮箱中，在进行引用，自行修改html
                        在html中引用使用方式为  src="cid:image2" 如下
                        <img  
                            src="cid:image2"
                            style="width: 601px; height: 338px;" id="img_insert_166558994361906185784892969268"  modifysize="97%" diffpixels="24px">
                        """
                    msgImage.add_header('Content-ID', f'<image{str(image_index)}>')
                    self.msg.attach(msgImage)
                    # print(f'<image{str(index + 1)}>', msgImage)
                #     <img src="cid:image1">
            text = MIMEText(mail_body, 'html', 'utf-8')
            self.msg.attach(text)
        # file_path = r'read.md'  #如果需要添加附件，就给定路径
        if file_path:  # 最开始的函数参数我默认设置了None ，想添加附件，自行更改一下就好
            docFile = file_path
            docApart = MIMEApplication(open(docFile, 'rb').read())
            docApart.add_header('Content-Disposition', 'attachment', filename=docFile)
            self.msg.attach(docApart)

        self.start_send(subject, to_user)



from setuptools import setup, find_packages

version = '0.0.2'  # Any format you want
DESCRIPTION = 'Easily cut the basic type by email_operations'

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    # 要显示的唯一标识（用于pip install xxx）
    name='email_operations',
    # 使用find_packages()自动发现项目中的所有包,如果不想使用所有的包，那么可以手动指定例如：packages=[‘package1’, ‘package2’, ‘package3’]
    packages=find_packages(),

    include_package_data=True,  # 打包包含静态文件标识！！上传静态数据时有用
    version=version,  # 版本号
    description='Short description',  # '包的简介描述'
    long_description_content_type="text/markdown",  # 包的详细介绍(一般通过加载README.md)
    long_description=long_description,  ## 长描述设置为README.md的内容
    author="SkyOceanChen",  # 作者
    author_email="skyoceanchen@foxmail.com",  # 作者的电子邮件
    url='https://gitee.com/SkyOceanchen/email_operations.git',  # 项目开源地址
    keywords=['basic_type', 'python', ],
    # 许可协议
    license='MIT',
    # 要安装的依赖包 ['py-L>=0.12.0', 'ter==3.1.0'],  # 指定了当前软件包所依赖的其他python类库。这些指定的python类库将会在本package被安装的时候一并被安装
    install_requires=[
        # All external pip packages you are importing
    ],
    classifiers=[  # 关于包的其他元数据(metadata)
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',  # 与操作系统无关
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',  # 根据MIT许可证开源
        'Programming Language :: Python :: 3.6',  # 该软件包仅与Python3兼容
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.10',
    ],

    python_requires='>=3'
)
"""
setup.py中的python_requires='>=3' 为要求python版本>=3，如果有更细致的要求写法：
# 大于等于3
python_requires='>=3'
# 大于等于3.3，但是不能超过4
python_requires='~=3.3'
# 不能用3.1,3.2
python_requires='!=3.1.*, !=3.2.*'

"""
"""
python setup.py bdist_wheel sdist
twine upload dist/*
SkyOceanChen/CHENziqing527#
"""



# @Time : 2021/11/21 17:18
# @Author : skyoceanchen
# @File : out.py
# @Software: PyCharm
# @PRODUCT_NAME: PyCharm
# @MONTH_NAME_SHORT:11月

import win32com.client as win32


def send_mail():
    outlook = win32.Dispatch('Outlook.Application')

    mail_item = outlook.CreateItem(0)  # 0: olMailItem

    mail_item.Recipients.Add('2331568246@qq.com')
    mail_item.Subject = 'Mail Test'

    mail_item.BodyFormat = 2  # 2: Html format
    mail_item.HTMLBody = '''
        <H2>Hello, This is a test mail.</H2>
        Hello Guys.
        '''
    mail_item.Attachments.Add(r'F:\pythonstudyother\automaticoffice\002common\邮箱\发送邮箱.py')
    mail_item.Send()


if __name__ == '__main__':
    send_mail()
